#!/usr/bin/perl
# -----------------------------------------------------------------------------
# Programm         : p o r t _ c h e c k . p l
# -----------------------------------------------------------------------------
# Autor            : Chrisian Dhl
# Erstellt         : 12. Juli 2003
# Zuletzt gendert : 22. Juli 2003
# Aufgabe          : Das Programm testet bestimmte Ports / Hosts auf Er-
#                    reichbarkeit und zeigt das Ergebnis optisch an.
#                    Der Test wird alle 10 Sekunden wiederholt.
#
#                    ACHTUNG: Fr echte Tests mssen die auskommentierten Zei-
#                             len in der Funktion testlauf() aktiuviert und
#                             die Zeile
#                                 my $socket = int rand 2;
#                             auskommentiert werden.
# -----------------------------------------------------------------------------
# Version 0.0.2
# -----------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Pakete / Pragmas
#------------------------------------------------------------------------------
use diagnostics;
use strict;
use warnings;

use IO::Socket;
use Tk;

use lib "./Check/"; # Damit Check.pm im Unterverzeichnis check gefunden wird.

use Check;

#------------------------------------------------------------------------------
# Globale Variablen:
#------------------------------------------------------------------------------
my @remote_host   = qw(192.168.0.1
                       192.168.0.2
                       192.168.0.5);
my @remote_port   = qw(3074
                       4950
                       4900);

#------------------------------------------------------------------------------
# TK-Hauptfenster:
#------------------------------------------------------------------------------
my $MW;
{
    $MW = MainWindow->new();

    #
    # Titel:
    #
    #$MW->title('C - h - e - c - k   V.' . Check::version() . ' (' .
    #                                      Check::datum() . ')');
    my @zeit     = localtime();
    my $zeit_str = sprintf "%02d.%02d.%04d %02d:%02d.%02d",
                       $zeit[3], $zeit[4]+1, $zeit[4]+1900,
                       $zeit[2], $zeit[1], $zeit[0];

    $MW->title('Host / Port Check - ' . $zeit_str);

    #
    # Icon:
    #
    my $icon = $MW->Photo(-file   => 'Check/res/check.bmp',
                          -height => 32,
                          -width  => 32,
                          );
    $MW->Icon(-image => $icon);

    #
    # Info-Frames:
    #
    my $frame = $MW->Frame(-border => 0,
                           -background => 'black',
                          )
                    ->pack(-expand => 1,
                           -fill   => 'both'
                          );
    my $f1 = $frame->Frame(-border => 0,
                           -background => 'black',
                          )
                    ->pack(-side => 'left',
                           -expand => 1,
                           -fill => 'both',
                          );
    my $f2 = $frame->Frame(-border => 0,
                           -background => 'black',
                          )
                    ->pack(-side => 'left',
                           -expand => 1,
                           -fill => 'both',
                          );
    $f1->Label(-text => 'Hosts:',
               -background => 'black',
               -foreground => 'yellow',
               -font       => '{Times New Roman} 14 {normal}'
              )
        ->pack(-anchor => 'w',
               -expand => 1,
               #-fill   => 'x',
              );
    for my $h (@remote_host) {
        $f1->Label(-text => '    '.$h,
                   -background => 'black',
                   -foreground => 'yellow',
                   -font       => '{Times New Roman} 14 {normal}'
                  )
            ->pack(-anchor => 'w',
                   -expand => 1,
                   #-fill   => 'x',
                  );
    }
    $f2->Label(-text => 'Ports:',
               -background => 'black',
               -foreground => 'yellow',
               -font       => '{Times New Roman} 14 {normal}'
              )
        ->pack(-anchor => 'w',
               -expand => 1,
               #-fill   => 'x',
              );
    for my $p (@remote_port) {
        $f2->Label(-text => '    '.$p,
                   -background => 'black',
                   -foreground => 'yellow',
                   -font       => '{Times New Roman} 14 {normal}'
                  )
            ->pack(-anchor => 'w',
                   -expand => 1,
                   #-fill   => 'x',
                  );
    }


    #
    # OK-Button:
    #
    my $ok = $MW->Button(-text        => 'Programmende',
                         -command     => sub { $MW->destroy() },
                         -default     => 'active',
                         -padx        => 15,
                        )
                  ->pack(-expand => '0',
                         -fill   => 'x',
                         -side   => 'bottom',
                        );

    #
    # Bindungen:
    #
    $MW->bind('<Return>', sub{$ok->invoke()});
    $MW->bind('<Escape>', sub{$ok->invoke()});

    #
    # Geometrie:
    #
    #$MW->geometry('300x40+10+10');
    #$MW->geometry('450x400+200+100');
    $MW->geometry('450x400');
}



#------------------------------------------------------------------------------
# Frame, in dem das Check-Ergebnis angezeigt wird (wird in Check.pm erzeugt):
#------------------------------------------------------------------------------
my $Frame = undef; # TopLevel-Frame des Check-Fensters


# -----------------------------------------------------------------------------
# sub          : t e s t l a u f
# -----------------------------------------------------------------------------
# Autor        : Christian Dhl
# Aufgabe      : Testlauf ber alle Hosts und Ports.
# Parameter    : Array, in welches das Ergebnis eingetragen wird.
# Rckgabewert : keiner (im bergebenen Array)
# -----------------------------------------------------------------------------
# 0.0.1 - 21.07.2003 - CD - Erstellt
# -----------------------------------------------------------------------------
sub testlauf {
    my $check = shift; # Referenz auf ein Array


    @$check = ();      # Array leeren

    for my $remote_host (@remote_host) {
        for my $remote_port (@remote_port) {
            #my $socket = IO::Socket::INET->new(PeerAddr => $remote_host,
            #                                   PeerPort => $remote_port,
            #                                   Proto    => "TCP",
            #                                   Type     => SOCK_STREAM,
            #                                  );
            my $socket = int rand 2;
            push @$check, {
                            Text => "Host $remote_host - Port $remote_port",
                            Test => $socket?1:0,
                          };
        }
    }
} # sub testlauf


# -----------------------------------------------------------------------------
# sub          : z e i g e _ a n
# -----------------------------------------------------------------------------
# Autor        : Christian Dhl
# Aufgabe      : Durchfhren und Anzeigen des Testlaufs.
# Parameter    : keine
# Rckgabewert : keiner
# -----------------------------------------------------------------------------
# 0.0.1 - 21.07.2003 - CD - Erstellt
# 0.0.2 - 21.07.2003 - CD - Zeitstamp-Titel + width + grab + x/ypos
# -----------------------------------------------------------------------------
sub zeige_an {
    my @check;

    $Frame->destroy() if defined $Frame;

    testlauf(\@check);

    my @zeit     = localtime();
    my $zeit_str = sprintf "%02d.%02d.%04d %02d:%02d.%02d",
                       $zeit[3], $zeit[4]+1, $zeit[4]+1900,
                       $zeit[2], $zeit[1], $zeit[0];
    $MW->title('Host / Port Check - ' . $zeit_str);

    my $c = Check->new(
                       mw      => \$MW,
                       check   => \@check,
                       lampen  => 2,
                       fenster => 2,
                       button  => 0,
                       status  => 0,
                      );
    $Frame = $c->show();
} # sub zeige_an


zeige_an();
$MW->repeat(10000, \&zeige_an);

MainLoop();


